/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2013-2023 Chaosdorf e.V.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package de.chaosdorf.meteroid.di

import de.chaosdorf.mete.DrinkId
import de.chaosdorf.meteroid.model.Drink
import de.chaosdorf.meteroid.Repository
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.flow.SharingStarted
import kotlinx.coroutines.flow.StateFlow
import kotlinx.coroutines.flow.stateIn

interface DrinkViewModelFactory {
  fun newInstance(
    scope: CoroutineScope,
    repository: Repository<DrinkId, Drink>
  ) = DrinkListViewModelImpl(scope, repository)
}

interface DrinkListViewModel {
  val drinks: StateFlow<List<Drink>>
}

class DrinkListViewModelImpl(
  scope: CoroutineScope,
  repository: Repository<DrinkId, Drink>
) : DrinkListViewModel {
  override val drinks: StateFlow<List<Drink>> = repository.getAllFlow()
    .stateIn(scope, SharingStarted.WhileSubscribed(), emptyList())
}
