/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2013-2023 Chaosdorf e.V.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package de.chaosdorf.meteroid.routes.setup

import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.Button
import androidx.compose.material3.LinearProgressIndicator
import androidx.compose.material3.ListItem
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.material3.TopAppBar
import androidx.compose.runtime.Composable
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.ui.Modifier
import coil.compose.AsyncImage
import de.chaosdorf.meteroid.di.AddServerViewModel

@Composable
fun AddServerRoute(viewModel: AddServerViewModel) {
  val url by viewModel.url.collectAsState()
  val server by viewModel.server.collectAsState()
  val loading by viewModel.loading.collectAsState()

  Scaffold(
    topBar = {
      TopAppBar(title = {
        Text("Add Server")
      })
    }
  ) { paddingValues ->
    Column(modifier = Modifier.padding(paddingValues)) {
      if (loading) {
        LinearProgressIndicator()
      }

      TextField(
        label = {
          Text("Server URL")
        },
        value = url,
        onValueChange = { value ->
          viewModel.url.value = value
        }
      )

      Button(
        onClick = viewModel::submit
      ) {
        Text("Save")
      }

      if (!viewModel.isFirstServer) {
        Button(
          onClick = viewModel::cancel
        ) {
          Text("Cancel")
        }
      }

      server?.let {
        ListItem(
          headlineContent = { Text(it.name ?: it.url) },
          leadingContent = {
            AsyncImage(model = it.logoUrl, contentDescription = null)
          }
        )
      }
    }
  }
}
